@@ -2,6 +2,6 @@
 
 test_that('REQUIRE TEST exp Monte Carlo', {
     z <- zexp$new()
-    test <- z$mcunit(plot = FALSE)
-    expect_true(test)
+    test.exp <- z$mcunit(plot = FALSE)
+    expect_true(test.exp)
 })
\ No newline at end of file
