@@ -2,6 +2,6 @@
 
 test_that('REQUIRE TEST poissonsurvey Monte Carlo', {
     z <- zpoissonsurvey$new()
-    test <- z$mcunit(plot = FALSE)
-    expect_true(test)
+    test.poissonsurvey <- z$mcunit(plot = FALSE)
+    expect_true(test.poissonsurvey)
 })
\ No newline at end of file
