@@ -2,6 +2,6 @@
 
 test_that('REQUIRE TEST probitsurvey Monte Carlo', {
     z <- zprobitsurvey$new()
-    test <- z$mcunit(plot = FALSE)
-    expect_true(test)
+    test.probitsurvey <- z$mcunit(minx=-1, maxx=1, plot = FALSE)
+    expect_true(test.probitsurvey)
 })
\ No newline at end of file
